Plyvel
======

**Plyvel** is a fast and feature-rich Python interface to LevelDB_.

Plyvel has a rich feature set, high performance, and a friendly Pythonic API.
See the documentation and project page for more information:

* Documentation_
* `Project page`_

.. _LevelDB: http://code.google.com/p/leveldb/
.. _Documentation: https://plyvel.readthedocs.org/
.. _Project page: https://github.com/wbolster/plyvel
